==> imixs-archive-service-2.2.7-sources.jar: org/imixs/archive/service/resync/ResyncStatusHandler.java <==
/*******************************************************************************
 *  Imixs Workflow Technology
 *  Copyright (C) 2001, 2008 Imixs Software Solutions GmbH,  
 *  http://www.imixs.com
 *  
 *  This program is free software; you can redistribute it and/or 
 *  modify it under the terms of the GNU General Public License 
 *  as published by the Free Software Foundation; either version 2 
 *  of the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful, 
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of 
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 *  General Public License for more details.
 *  
 *  You can receive a copy of the GNU General Public
 *  License at http://www.gnu.org/licenses/gpl.html
 *  
 *  Contributors:  
 *  	Imixs Software Solutions GmbH - initial API and implementation
 *  	Ralph Soika
 *******************************************************************************/
package org.imixs.archive.service.resync;

import javax.ejb.Singleton;

/**
 * The ImportStatusHandler provides a status flag for the ImportService
 * 
 * @version 1.0
 * @author rsoika
 */
@Singleton
public class ResyncStatusHandler {

    public static final byte STAUS_RUNNING = 1;
    public static final byte STAUS_STOPPED = 0;
    public static final byte STAUS_CANCELED = 2;

    private byte status = 0;

    public byte getStatus() {
        return status;
    }

    public void setStatus(byte status) {
        this.status = status;
    }

}

==> imixs-archive-service-3.0.0-sources.jar: org/imixs/archive/service/resync/ResyncStatusHandler.java <==
/*******************************************************************************
 *  Imixs Workflow Technology
 *  Copyright (C) 2001, 2008 Imixs Software Solutions GmbH,  
 *  http://www.imixs.com
 *  
 *  This program is free software; you can redistribute it and/or 
 *  modify it under the terms of the GNU General Public License 
 *  as published by the Free Software Foundation; either version 2 
 *  of the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful, 
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of 
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
 *  General Public License for more details.
 *  
 *  You can receive a copy of the GNU General Public
 *  License at http://www.gnu.org/licenses/gpl.html
 *  
 *  Contributors:  
 *  	Imixs Software Solutions GmbH - initial API and implementation
 *  	Ralph Soika
 *******************************************************************************/
package org.imixs.archive.service.resync;

import jakarta.ejb.Singleton;

/**
 * The ImportStatusHandler provides a status flag for the ImportService
 * 
 * @version 1.0
 * @author rsoika
 */
@Singleton
public class ResyncStatusHandler {

    public static final byte STAUS_RUNNING = 1;
    public static final byte STAUS_STOPPED = 0;
    public static final byte STAUS_CANCELED = 2;

    private byte status = 0;

    public byte getStatus() {
        return status;
    }

    public void setStatus(byte status) {
        this.status = status;
    }

}
